import { BadgeProps, TooltipProps } from '@mui/material';
import React, { ComponentType, ReactElement } from 'react';
import { ActionColor, ActionPath, ActionSize } from '../../../types/action';
import { BaseProps } from '../../../types/props';
import { Visibility } from '../../../types/visibility';
import { ConfirmationDialogProps } from '../../dialogs/confirmationDialog';
import { ErrorsDialogProps } from '../../dialogs/errorsDialog';
import { OnSubmitFailedHandler, OnSubmitHandler, OnSubmittedHandler } from '../../hooks/useSubmit';
export declare const actionClasses: {
    link: string;
    button: string;
    icon: string;
    fab: string;
    modal: string;
    modaless: string;
    disabled: string;
    navigate: string;
    submit: string;
};
export declare type ActionVariant = 'link' | 'fab' | 'icon-button' | 'button' | 'custom';
export interface ActionBaseProps extends BaseProps {
    /**
     * Content of the component.
     */
    children?: React.ReactNode;
    /**
     * Action button variant
     */
    variant?: ActionVariant;
    /**
     * Optional action title.
     */
    title?: React.ReactNode;
    /**
     * Data context in which action has been executed. Could be item in the list, multiple items...
     */
    data?: any;
    /**
     * Optional icon used to visually identify action.
     */
    icon?: React.ReactNode;
    /**
     * Color of the action.
     */
    color?: ActionColor;
    /**
     * Relative action button size.
     */
    size?: ActionSize;
    /**
     * Specifies if action is disabled.
     */
    disabled?: boolean;
    /**
     * Optional action tooltip.
     */
    tooltip?: React.ReactNode;
    /**
     * Tooltip props for the action.
     */
    TooltipProps?: Omit<TooltipProps, 'title' | 'children'>;
    /**
     * Action badge props.
     */
    badge?: React.ReactElement<BadgeProps>;
    /**
     * Custom action component.
     */
    Component?: ComponentType<any>;
    /**
     * Underlying component  props. Underlying component depends on action variant.
     */
    ComponentProps?: any;
    /**
     * Specifies if action should be visible or not.
     */
    visibility?: Visibility;
    /**
     * Underluing error dialog props.
     */
    ErrorsDialogProps?: ErrorsDialogProps;
}
export interface OnSubmittedProps {
    /**
     * Dialog which is shown when submit is completed successfully.
     */
    submittedConfirmationDialog?: ReactElement<ConfirmationDialogProps>;
    /**
     * Callback function to be called if submit succeeded.
     */
    onSubmitted?: OnSubmittedHandler;
    /**
     * Specifies if navigations goes back after submit. Shortcut for onSubmitted = {() => navigate(-1)}.
     * onSubmitted if specified executes before the back navigation.
     */
    navigateBackOnSubmitted?: boolean;
    /**
     * Callback function to be called if submit failed.
     */
    onSubmitFailed?: OnSubmitFailedHandler;
}
export interface ActionSubmitProps extends OnSubmittedProps {
    /**
     * Hadler for submit action.
     */
    onSubmit?: OnSubmitHandler;
    /**
     * Modal dialog props.
     */
    modalDialog?: any;
}
export interface ActionNavigationProps {
    /**
     * Provides destination of the action in the form of `react-router-dom` link.
     * This will be treated only if onSubmit is not specified.
     */
    to?: ActionPath;
    /**
     * Parameters used to specialize link (usually identifier of the resource, or some other parameter which will be used to execute specified action).
     * It could be a function with a single parameter providing input data: execution of the function should return object containing parameters.
     */
    params?: any;
}
