import { FieldInputVariant, FieldSize, FieldVariant, FieldWidth } from '../../types/field';
import React, { ReactNode } from 'react';
import { BaseProps } from '../../types/props';
import { FilterOptions } from '../../types/search';
export interface FieldProps extends BaseProps {
    /**
     * Underlying input's name.
     */
    name: string;
    /**
     * Specifies if field is hidden.
     */
    hidden?: boolean;
    /**
     * Specifies if field is disabled.
     */
    disabled?: boolean;
    /**
     * Label of the field.
     */
    label?: ReactNode;
    /**
     * Field's placeholder.
     */
    placeholder?: string;
    /**
     * Variant of the field implies used control.
     */
    variant?: FieldVariant;
    /**
     * Options are relevant when underlying field control has an option to select from multiple values.
     */
    options?: FilterOptions;
    /**
     * Custom component used to render the field. Use it in the case when provided variants are not sufficient.
     */
    Component?: React.ComponentType<any>;
    /**
     * When functionality could not be achieved by regular properties of the FieldProps,
     * then use this as a portal to provide additional props to the underlying component.
     * Most of the fields variant are implemented using Mui 'TextField' component. In that case this prop map to 'InputProps'.
     * Some variants of fieds are not implemented using 'TextField' in that case this destcructs to the underlying component.
     * See interface of the underlying component for more details on availabe props:
     * - 'number': NumberFormat from 'react-number-format'
     */
    ComponentProps?: any;
    /**
     * Relative field width (depends on size of viewport, i.e., for wide screen size):
     * 'thin': 25% of container
     * 'narrow': 50% of container
     * 'wide': 75% of container.
     * 'full': 100% of container.
     *
     * default: 'full' except when have siblings when default is 'narrow'
     */
    width?: FieldWidth;
    /**
     * 'react-hook-form' control.
     */
    control?: any;
    /**
     * 'react-hook-form' rules.
     */
    rules?: any;
    /**
     * Underlying TextField (or similar control) variant.
     */
    fieldInputVariant?: FieldInputVariant;
    /**
     * Field size.
     */
    fieldSize?: FieldSize;
    /**
     * Validation error for the field.
     */
    error?: any;
}
declare const Field: React.ForwardRefExoticComponent<FieldProps & React.RefAttributes<unknown>>;
export default Field;
