import { BaseProps } from '../../types/props';
import React from 'react';
import { ColorDisplayProps } from '../display/colorDisplay';
import { BoxProps, InputLabelProps, TextFieldProps } from '@mui/material';
export declare type ColorInputProps = BaseProps & TextFieldProps & {
    /**
     * Specifies callback function to be called when value has been changed.
     */
    onChange?: (item: string) => void;
    /***
     * Specifies if component is disabled.
     */
    disabled?: boolean;
    /**
     * Specifies the variant of the color picker.
     */
    pickerVariant?: 'none' | 'block' | 'chrome' | 'circle' | 'compact' | 'github' | 'hue-alpha' | 'hue' | 'alpha' | 'material' | 'sketch' | 'slider' | 'swatches' | 'twitter';
    /**
     * Specifies if color picker is rendered as an inline control.
     */
    inline?: boolean;
    /**
     * Automatically closes picked when picker's OnChangeComplete event fired.
     */
    closePickerOnChangeComplete?: boolean;
    /**
     * Underlying ColorDisplay props.
     */
    ColorDisplayProps?: ColorDisplayProps;
    /**
     * Underlying color picker props. Depend on pickerVariant value.
     */
    PickerComponentProps?: any;
    /**
     * Underlying picker Box props.
     */
    PickerBoxProps?: BoxProps;
    /**
     * Underlying wrapper Box props.
     */
    BoxProps?: BoxProps;
    /**
     * Underlying InputLabel props.
     */
    InputLabelProps?: InputLabelProps;
};
declare const ColorInput: React.ForwardRefExoticComponent<(Pick<BaseProps & import("@mui/material").FilledTextFieldProps & {
    /**
     * Specifies callback function to be called when value has been changed.
     */
    onChange?: ((item: string) => void) | undefined;
    /***
     * Specifies if component is disabled.
     */
    disabled?: boolean | undefined;
    /**
     * Specifies the variant of the color picker.
     */
    pickerVariant?: "circle" | "none" | "slider" | "block" | "alpha" | "hue" | "compact" | "chrome" | "github" | "hue-alpha" | "material" | "sketch" | "swatches" | "twitter" | undefined;
    /**
     * Specifies if color picker is rendered as an inline control.
     */
    inline?: boolean | undefined;
    /**
     * Automatically closes picked when picker's OnChangeComplete event fired.
     */
    closePickerOnChangeComplete?: boolean | undefined;
    /**
     * Underlying ColorDisplay props.
     */
    ColorDisplayProps?: ColorDisplayProps | undefined;
    /**
     * Underlying color picker props. Depend on pickerVariant value.
     */
    PickerComponentProps?: any;
    /**
     * Underlying picker Box props.
     */
    PickerBoxProps?: import("@mui/material/OverridableComponent").OverrideProps<import("@mui/system").BoxTypeMap<{}, "div", import("@mui/material").Theme>, "div"> | undefined;
    /**
     * Underlying wrapper Box props.
     */
    BoxProps?: import("@mui/material/OverridableComponent").OverrideProps<import("@mui/system").BoxTypeMap<{}, "div", import("@mui/material").Theme>, "div"> | undefined;
    /**
     * Underlying InputLabel props.
     */
    InputLabelProps?: import("@mui/material/OverridableComponent").OverrideProps<import("@mui/material").InputLabelTypeMap<{}, "label">, "label"> | undefined;
}, "children" | "variant" | "title" | "color" | "size" | "disabled" | "className" | "onSubmit" | "classes" | "defaultChecked" | "defaultValue" | "suppressContentEditableWarning" | "suppressHydrationWarning" | "accessKey" | "autoFocus" | "contentEditable" | "contextMenu" | "dir" | "draggable" | "hidden" | "id" | "lang" | "nonce" | "placeholder" | "slot" | "spellCheck" | "style" | "tabIndex" | "translate" | "radioGroup" | "role" | "about" | "content" | "datatype" | "inlist" | "prefix" | "property" | "rel" | "resource" | "rev" | "typeof" | "vocab" | "autoCapitalize" | "autoCorrect" | "autoSave" | "itemProp" | "itemScope" | "itemType" | "itemID" | "itemRef" | "results" | "security" | "unselectable" | "inputMode" | "is" | "aria-activedescendant" | "aria-atomic" | "aria-autocomplete" | "aria-busy" | "aria-checked" | "aria-colcount" | "aria-colindex" | "aria-colspan" | "aria-controls" | "aria-current" | "aria-describedby" | "aria-details" | "aria-disabled" | "aria-dropeffect" | "aria-errormessage" | "aria-expanded" | "aria-flowto" | "aria-grabbed" | "aria-haspopup" | "aria-hidden" | "aria-invalid" | "aria-keyshortcuts" | "aria-label" | "aria-labelledby" | "aria-level" | "aria-live" | "aria-modal" | "aria-multiline" | "aria-multiselectable" | "aria-orientation" | "aria-owns" | "aria-placeholder" | "aria-posinset" | "aria-pressed" | "aria-readonly" | "aria-relevant" | "aria-required" | "aria-roledescription" | "aria-rowcount" | "aria-rowindex" | "aria-rowspan" | "aria-selected" | "aria-setsize" | "aria-sort" | "aria-valuemax" | "aria-valuemin" | "aria-valuenow" | "aria-valuetext" | "dangerouslySetInnerHTML" | "onCopy" | "onCopyCapture" | "onCut" | "onCutCapture" | "onPaste" | "onPasteCapture" | "onCompositionEnd" | "onCompositionEndCapture" | "onCompositionStart" | "onCompositionStartCapture" | "onCompositionUpdate" | "onCompositionUpdateCapture" | "onFocus" | "onFocusCapture" | "onBlur" | "onBlurCapture" | "onChange" | "onChangeCapture" | "onBeforeInput" | "onBeforeInputCapture" | "onInput" | "onInputCapture" | "onReset" | "onResetCapture" | "onSubmitCapture" | "onInvalid" | "onInvalidCapture" | "onLoad" | "onLoadCapture" | "onError" | "onErrorCapture" | "onKeyDown" | "onKeyDownCapture" | "onKeyPress" | "onKeyPressCapture" | "onKeyUp" | "onKeyUpCapture" | "onAbort" | "onAbortCapture" | "onCanPlay" | "onCanPlayCapture" | "onCanPlayThrough" | "onCanPlayThroughCapture" | "onDurationChange" | "onDurationChangeCapture" | "onEmptied" | "onEmptiedCapture" | "onEncrypted" | "onEncryptedCapture" | "onEnded" | "onEndedCapture" | "onLoadedData" | "onLoadedDataCapture" | "onLoadedMetadata" | "onLoadedMetadataCapture" | "onLoadStart" | "onLoadStartCapture" | "onPause" | "onPauseCapture" | "onPlay" | "onPlayCapture" | "onPlaying" | "onPlayingCapture" | "onProgress" | "onProgressCapture" | "onRateChange" | "onRateChangeCapture" | "onResize" | "onResizeCapture" | "onSeeked" | "onSeekedCapture" | "onSeeking" | "onSeekingCapture" | "onStalled" | "onStalledCapture" | "onSuspend" | "onSuspendCapture" | "onTimeUpdate" | "onTimeUpdateCapture" | "onVolumeChange" | "onVolumeChangeCapture" | "onWaiting" | "onWaitingCapture" | "onAuxClick" | "onAuxClickCapture" | "onClick" | "onClickCapture" | "onContextMenu" | "onContextMenuCapture" | "onDoubleClick" | "onDoubleClickCapture" | "onDrag" | "onDragCapture" | "onDragEnd" | "onDragEndCapture" | "onDragEnter" | "onDragEnterCapture" | "onDragExit" | "onDragExitCapture" | "onDragLeave" | "onDragLeaveCapture" | "onDragOver" | "onDragOverCapture" | "onDragStart" | "onDragStartCapture" | "onDrop" | "onDropCapture" | "onMouseDown" | "onMouseDownCapture" | "onMouseEnter" | "onMouseLeave" | "onMouseMove" | "onMouseMoveCapture" | "onMouseOut" | "onMouseOutCapture" | "onMouseOver" | "onMouseOverCapture" | "onMouseUp" | "onMouseUpCapture" | "onSelect" | "onSelectCapture" | "onTouchCancel" | "onTouchCancelCapture" | "onTouchEnd" | "onTouchEndCapture" | "onTouchMove" | "onTouchMoveCapture" | "onTouchStart" | "onTouchStartCapture" | "onPointerDown" | "onPointerDownCapture" | "onPointerMove" | "onPointerMoveCapture" | "onPointerUp" | "onPointerUpCapture" | "onPointerCancel" | "onPointerCancelCapture" | "onPointerEnter" | "onPointerEnterCapture" | "onPointerLeave" | "onPointerLeaveCapture" | "onPointerOver" | "onPointerOverCapture" | "onPointerOut" | "onPointerOutCapture" | "onGotPointerCapture" | "onGotPointerCaptureCapture" | "onLostPointerCapture" | "onLostPointerCaptureCapture" | "onScroll" | "onScrollCapture" | "onWheel" | "onWheelCapture" | "onAnimationStart" | "onAnimationStartCapture" | "onAnimationEnd" | "onAnimationEndCapture" | "onAnimationIteration" | "onAnimationIterationCapture" | "onTransitionEnd" | "onTransitionEndCapture" | "sx" | "label" | "select" | "error" | "key" | "name" | "type" | "value" | "autoComplete" | "required" | "rows" | "margin" | "inline" | "fullWidth" | "inputProps" | "inputRef" | "focused" | "hiddenLabel" | "InputProps" | "FormHelperTextProps" | "helperText" | "InputLabelProps" | "multiline" | "maxRows" | "minRows" | "SelectProps" | "pickerVariant" | "closePickerOnChangeComplete" | "ColorDisplayProps" | "PickerComponentProps" | "PickerBoxProps" | "BoxProps"> & React.RefAttributes<unknown>) | (Pick<BaseProps & import("@mui/material").StandardTextFieldProps & {
    /**
     * Specifies callback function to be called when value has been changed.
     */
    onChange?: ((item: string) => void) | undefined;
    /***
     * Specifies if component is disabled.
     */
    disabled?: boolean | undefined;
    /**
     * Specifies the variant of the color picker.
     */
    pickerVariant?: "circle" | "none" | "slider" | "block" | "alpha" | "hue" | "compact" | "chrome" | "github" | "hue-alpha" | "material" | "sketch" | "swatches" | "twitter" | undefined;
    /**
     * Specifies if color picker is rendered as an inline control.
     */
    inline?: boolean | undefined;
    /**
     * Automatically closes picked when picker's OnChangeComplete event fired.
     */
    closePickerOnChangeComplete?: boolean | undefined;
    /**
     * Underlying ColorDisplay props.
     */
    ColorDisplayProps?: ColorDisplayProps | undefined;
    /**
     * Underlying color picker props. Depend on pickerVariant value.
     */
    PickerComponentProps?: any;
    /**
     * Underlying picker Box props.
     */
    PickerBoxProps?: import("@mui/material/OverridableComponent").OverrideProps<import("@mui/system").BoxTypeMap<{}, "div", import("@mui/material").Theme>, "div"> | undefined;
    /**
     * Underlying wrapper Box props.
     */
    BoxProps?: import("@mui/material/OverridableComponent").OverrideProps<import("@mui/system").BoxTypeMap<{}, "div", import("@mui/material").Theme>, "div"> | undefined;
    /**
     * Underlying InputLabel props.
     */
    InputLabelProps?: import("@mui/material/OverridableComponent").OverrideProps<import("@mui/material").InputLabelTypeMap<{}, "label">, "label"> | undefined;
}, "children" | "variant" | "title" | "color" | "size" | "disabled" | "className" | "onSubmit" | "classes" | "defaultChecked" | "defaultValue" | "suppressContentEditableWarning" | "suppressHydrationWarning" | "accessKey" | "autoFocus" | "contentEditable" | "contextMenu" | "dir" | "draggable" | "hidden" | "id" | "lang" | "nonce" | "placeholder" | "slot" | "spellCheck" | "style" | "tabIndex" | "translate" | "radioGroup" | "role" | "about" | "content" | "datatype" | "inlist" | "prefix" | "property" | "rel" | "resource" | "rev" | "typeof" | "vocab" | "autoCapitalize" | "autoCorrect" | "autoSave" | "itemProp" | "itemScope" | "itemType" | "itemID" | "itemRef" | "results" | "security" | "unselectable" | "inputMode" | "is" | "aria-activedescendant" | "aria-atomic" | "aria-autocomplete" | "aria-busy" | "aria-checked" | "aria-colcount" | "aria-colindex" | "aria-colspan" | "aria-controls" | "aria-current" | "aria-describedby" | "aria-details" | "aria-disabled" | "aria-dropeffect" | "aria-errormessage" | "aria-expanded" | "aria-flowto" | "aria-grabbed" | "aria-haspopup" | "aria-hidden" | "aria-invalid" | "aria-keyshortcuts" | "aria-label" | "aria-labelledby" | "aria-level" | "aria-live" | "aria-modal" | "aria-multiline" | "aria-multiselectable" | "aria-orientation" | "aria-owns" | "aria-placeholder" | "aria-posinset" | "aria-pressed" | "aria-readonly" | "aria-relevant" | "aria-required" | "aria-roledescription" | "aria-rowcount" | "aria-rowindex" | "aria-rowspan" | "aria-selected" | "aria-setsize" | "aria-sort" | "aria-valuemax" | "aria-valuemin" | "aria-valuenow" | "aria-valuetext" | "dangerouslySetInnerHTML" | "onCopy" | "onCopyCapture" | "onCut" | "onCutCapture" | "onPaste" | "onPasteCapture" | "onCompositionEnd" | "onCompositionEndCapture" | "onCompositionStart" | "onCompositionStartCapture" | "onCompositionUpdate" | "onCompositionUpdateCapture" | "onFocus" | "onFocusCapture" | "onBlur" | "onBlurCapture" | "onChange" | "onChangeCapture" | "onBeforeInput" | "onBeforeInputCapture" | "onInput" | "onInputCapture" | "onReset" | "onResetCapture" | "onSubmitCapture" | "onInvalid" | "onInvalidCapture" | "onLoad" | "onLoadCapture" | "onError" | "onErrorCapture" | "onKeyDown" | "onKeyDownCapture" | "onKeyPress" | "onKeyPressCapture" | "onKeyUp" | "onKeyUpCapture" | "onAbort" | "onAbortCapture" | "onCanPlay" | "onCanPlayCapture" | "onCanPlayThrough" | "onCanPlayThroughCapture" | "onDurationChange" | "onDurationChangeCapture" | "onEmptied" | "onEmptiedCapture" | "onEncrypted" | "onEncryptedCapture" | "onEnded" | "onEndedCapture" | "onLoadedData" | "onLoadedDataCapture" | "onLoadedMetadata" | "onLoadedMetadataCapture" | "onLoadStart" | "onLoadStartCapture" | "onPause" | "onPauseCapture" | "onPlay" | "onPlayCapture" | "onPlaying" | "onPlayingCapture" | "onProgress" | "onProgressCapture" | "onRateChange" | "onRateChangeCapture" | "onResize" | "onResizeCapture" | "onSeeked" | "onSeekedCapture" | "onSeeking" | "onSeekingCapture" | "onStalled" | "onStalledCapture" | "onSuspend" | "onSuspendCapture" | "onTimeUpdate" | "onTimeUpdateCapture" | "onVolumeChange" | "onVolumeChangeCapture" | "onWaiting" | "onWaitingCapture" | "onAuxClick" | "onAuxClickCapture" | "onClick" | "onClickCapture" | "onContextMenu" | "onContextMenuCapture" | "onDoubleClick" | "onDoubleClickCapture" | "onDrag" | "onDragCapture" | "onDragEnd" | "onDragEndCapture" | "onDragEnter" | "onDragEnterCapture" | "onDragExit" | "onDragExitCapture" | "onDragLeave" | "onDragLeaveCapture" | "onDragOver" | "onDragOverCapture" | "onDragStart" | "onDragStartCapture" | "onDrop" | "onDropCapture" | "onMouseDown" | "onMouseDownCapture" | "onMouseEnter" | "onMouseLeave" | "onMouseMove" | "onMouseMoveCapture" | "onMouseOut" | "onMouseOutCapture" | "onMouseOver" | "onMouseOverCapture" | "onMouseUp" | "onMouseUpCapture" | "onSelect" | "onSelectCapture" | "onTouchCancel" | "onTouchCancelCapture" | "onTouchEnd" | "onTouchEndCapture" | "onTouchMove" | "onTouchMoveCapture" | "onTouchStart" | "onTouchStartCapture" | "onPointerDown" | "onPointerDownCapture" | "onPointerMove" | "onPointerMoveCapture" | "onPointerUp" | "onPointerUpCapture" | "onPointerCancel" | "onPointerCancelCapture" | "onPointerEnter" | "onPointerEnterCapture" | "onPointerLeave" | "onPointerLeaveCapture" | "onPointerOver" | "onPointerOverCapture" | "onPointerOut" | "onPointerOutCapture" | "onGotPointerCapture" | "onGotPointerCaptureCapture" | "onLostPointerCapture" | "onLostPointerCaptureCapture" | "onScroll" | "onScrollCapture" | "onWheel" | "onWheelCapture" | "onAnimationStart" | "onAnimationStartCapture" | "onAnimationEnd" | "onAnimationEndCapture" | "onAnimationIteration" | "onAnimationIterationCapture" | "onTransitionEnd" | "onTransitionEndCapture" | "sx" | "label" | "select" | "error" | "key" | "name" | "type" | "value" | "autoComplete" | "required" | "rows" | "margin" | "inline" | "fullWidth" | "inputProps" | "inputRef" | "focused" | "hiddenLabel" | "InputProps" | "FormHelperTextProps" | "helperText" | "InputLabelProps" | "multiline" | "maxRows" | "minRows" | "SelectProps" | "pickerVariant" | "closePickerOnChangeComplete" | "ColorDisplayProps" | "PickerComponentProps" | "PickerBoxProps" | "BoxProps"> & React.RefAttributes<unknown>) | (Pick<BaseProps & import("@mui/material").OutlinedTextFieldProps & {
    /**
     * Specifies callback function to be called when value has been changed.
     */
    onChange?: ((item: string) => void) | undefined;
    /***
     * Specifies if component is disabled.
     */
    disabled?: boolean | undefined;
    /**
     * Specifies the variant of the color picker.
     */
    pickerVariant?: "circle" | "none" | "slider" | "block" | "alpha" | "hue" | "compact" | "chrome" | "github" | "hue-alpha" | "material" | "sketch" | "swatches" | "twitter" | undefined;
    /**
     * Specifies if color picker is rendered as an inline control.
     */
    inline?: boolean | undefined;
    /**
     * Automatically closes picked when picker's OnChangeComplete event fired.
     */
    closePickerOnChangeComplete?: boolean | undefined;
    /**
     * Underlying ColorDisplay props.
     */
    ColorDisplayProps?: ColorDisplayProps | undefined;
    /**
     * Underlying color picker props. Depend on pickerVariant value.
     */
    PickerComponentProps?: any;
    /**
     * Underlying picker Box props.
     */
    PickerBoxProps?: import("@mui/material/OverridableComponent").OverrideProps<import("@mui/system").BoxTypeMap<{}, "div", import("@mui/material").Theme>, "div"> | undefined;
    /**
     * Underlying wrapper Box props.
     */
    BoxProps?: import("@mui/material/OverridableComponent").OverrideProps<import("@mui/system").BoxTypeMap<{}, "div", import("@mui/material").Theme>, "div"> | undefined;
    /**
     * Underlying InputLabel props.
     */
    InputLabelProps?: import("@mui/material/OverridableComponent").OverrideProps<import("@mui/material").InputLabelTypeMap<{}, "label">, "label"> | undefined;
}, "children" | "variant" | "title" | "color" | "size" | "disabled" | "className" | "onSubmit" | "classes" | "defaultChecked" | "defaultValue" | "suppressContentEditableWarning" | "suppressHydrationWarning" | "accessKey" | "autoFocus" | "contentEditable" | "contextMenu" | "dir" | "draggable" | "hidden" | "id" | "lang" | "nonce" | "placeholder" | "slot" | "spellCheck" | "style" | "tabIndex" | "translate" | "radioGroup" | "role" | "about" | "content" | "datatype" | "inlist" | "prefix" | "property" | "rel" | "resource" | "rev" | "typeof" | "vocab" | "autoCapitalize" | "autoCorrect" | "autoSave" | "itemProp" | "itemScope" | "itemType" | "itemID" | "itemRef" | "results" | "security" | "unselectable" | "inputMode" | "is" | "aria-activedescendant" | "aria-atomic" | "aria-autocomplete" | "aria-busy" | "aria-checked" | "aria-colcount" | "aria-colindex" | "aria-colspan" | "aria-controls" | "aria-current" | "aria-describedby" | "aria-details" | "aria-disabled" | "aria-dropeffect" | "aria-errormessage" | "aria-expanded" | "aria-flowto" | "aria-grabbed" | "aria-haspopup" | "aria-hidden" | "aria-invalid" | "aria-keyshortcuts" | "aria-label" | "aria-labelledby" | "aria-level" | "aria-live" | "aria-modal" | "aria-multiline" | "aria-multiselectable" | "aria-orientation" | "aria-owns" | "aria-placeholder" | "aria-posinset" | "aria-pressed" | "aria-readonly" | "aria-relevant" | "aria-required" | "aria-roledescription" | "aria-rowcount" | "aria-rowindex" | "aria-rowspan" | "aria-selected" | "aria-setsize" | "aria-sort" | "aria-valuemax" | "aria-valuemin" | "aria-valuenow" | "aria-valuetext" | "dangerouslySetInnerHTML" | "onCopy" | "onCopyCapture" | "onCut" | "onCutCapture" | "onPaste" | "onPasteCapture" | "onCompositionEnd" | "onCompositionEndCapture" | "onCompositionStart" | "onCompositionStartCapture" | "onCompositionUpdate" | "onCompositionUpdateCapture" | "onFocus" | "onFocusCapture" | "onBlur" | "onBlurCapture" | "onChange" | "onChangeCapture" | "onBeforeInput" | "onBeforeInputCapture" | "onInput" | "onInputCapture" | "onReset" | "onResetCapture" | "onSubmitCapture" | "onInvalid" | "onInvalidCapture" | "onLoad" | "onLoadCapture" | "onError" | "onErrorCapture" | "onKeyDown" | "onKeyDownCapture" | "onKeyPress" | "onKeyPressCapture" | "onKeyUp" | "onKeyUpCapture" | "onAbort" | "onAbortCapture" | "onCanPlay" | "onCanPlayCapture" | "onCanPlayThrough" | "onCanPlayThroughCapture" | "onDurationChange" | "onDurationChangeCapture" | "onEmptied" | "onEmptiedCapture" | "onEncrypted" | "onEncryptedCapture" | "onEnded" | "onEndedCapture" | "onLoadedData" | "onLoadedDataCapture" | "onLoadedMetadata" | "onLoadedMetadataCapture" | "onLoadStart" | "onLoadStartCapture" | "onPause" | "onPauseCapture" | "onPlay" | "onPlayCapture" | "onPlaying" | "onPlayingCapture" | "onProgress" | "onProgressCapture" | "onRateChange" | "onRateChangeCapture" | "onResize" | "onResizeCapture" | "onSeeked" | "onSeekedCapture" | "onSeeking" | "onSeekingCapture" | "onStalled" | "onStalledCapture" | "onSuspend" | "onSuspendCapture" | "onTimeUpdate" | "onTimeUpdateCapture" | "onVolumeChange" | "onVolumeChangeCapture" | "onWaiting" | "onWaitingCapture" | "onAuxClick" | "onAuxClickCapture" | "onClick" | "onClickCapture" | "onContextMenu" | "onContextMenuCapture" | "onDoubleClick" | "onDoubleClickCapture" | "onDrag" | "onDragCapture" | "onDragEnd" | "onDragEndCapture" | "onDragEnter" | "onDragEnterCapture" | "onDragExit" | "onDragExitCapture" | "onDragLeave" | "onDragLeaveCapture" | "onDragOver" | "onDragOverCapture" | "onDragStart" | "onDragStartCapture" | "onDrop" | "onDropCapture" | "onMouseDown" | "onMouseDownCapture" | "onMouseEnter" | "onMouseLeave" | "onMouseMove" | "onMouseMoveCapture" | "onMouseOut" | "onMouseOutCapture" | "onMouseOver" | "onMouseOverCapture" | "onMouseUp" | "onMouseUpCapture" | "onSelect" | "onSelectCapture" | "onTouchCancel" | "onTouchCancelCapture" | "onTouchEnd" | "onTouchEndCapture" | "onTouchMove" | "onTouchMoveCapture" | "onTouchStart" | "onTouchStartCapture" | "onPointerDown" | "onPointerDownCapture" | "onPointerMove" | "onPointerMoveCapture" | "onPointerUp" | "onPointerUpCapture" | "onPointerCancel" | "onPointerCancelCapture" | "onPointerEnter" | "onPointerEnterCapture" | "onPointerLeave" | "onPointerLeaveCapture" | "onPointerOver" | "onPointerOverCapture" | "onPointerOut" | "onPointerOutCapture" | "onGotPointerCapture" | "onGotPointerCaptureCapture" | "onLostPointerCapture" | "onLostPointerCaptureCapture" | "onScroll" | "onScrollCapture" | "onWheel" | "onWheelCapture" | "onAnimationStart" | "onAnimationStartCapture" | "onAnimationEnd" | "onAnimationEndCapture" | "onAnimationIteration" | "onAnimationIterationCapture" | "onTransitionEnd" | "onTransitionEndCapture" | "sx" | "label" | "select" | "error" | "key" | "name" | "type" | "value" | "autoComplete" | "required" | "rows" | "margin" | "inline" | "fullWidth" | "inputProps" | "inputRef" | "focused" | "hiddenLabel" | "InputProps" | "FormHelperTextProps" | "helperText" | "InputLabelProps" | "multiline" | "maxRows" | "minRows" | "SelectProps" | "pickerVariant" | "closePickerOnChangeComplete" | "ColorDisplayProps" | "PickerComponentProps" | "PickerBoxProps" | "BoxProps"> & React.RefAttributes<unknown>)>;
export default ColorInput;
