import { SwipeableDrawerProps } from '@mui/material';
import { IconButtonProps } from '@mui/material/IconButton';
import { ListProps } from '@mui/material/List';
import { PaperProps } from '@mui/material/Paper';
import React from 'react';
import { HeaderColor, SidemenuState, SidemenuVariant } from '../../../types/layout';
import { Elevation } from '../../display/elevationScroll';
import { BaseProps } from '../../../types/props';
import { ActionSize } from '../../../types/action';
export declare type ToggleSidemenuFunction = () => void;
/**
 * Returns possible sidemenu state.
 * @param variant
 * @param state
 * @param minimizable
 * @returns
 */
export declare const getPossibleSidemenuState: (variant: SidemenuVariant, state: SidemenuState, minimizable: boolean) => "hidden" | "expanded" | "minimized";
/**
 * Decides new sidemenu state based on current state.
 */
export declare const toggleSidemenuState: (variant: SidemenuVariant, currentState: SidemenuState) => SidemenuState;
/**
 * Decides new sidemenu state based on current state.
 * This is for the case when temporary sidemenu automatically toggles.
 */
export declare const setTemporarySidemenuState: (originalVariant: SidemenuVariant, variant: SidemenuVariant, currentState: SidemenuState) => SidemenuState;
export interface SidemenuProps extends BaseProps, Omit<SwipeableDrawerProps, 'onClose' | 'open' | 'onOpen'> {
    /**
     * If `true`, the component is clipped under the AppHeader.
     * @default false
     */
    clipped?: boolean;
    /**
     * State of the corresponding sidemenu.
     */
    state?: SidemenuState;
    /**
     * If `true`, the component does not have border.
     * @default false
     */
    borderless?: boolean;
    /**
     * Non clipped, not minimized header content.
     */
    headerContent?: React.ReactNode;
    /** The color of the component. It supports those theme colors that make sense for this component.
     * @default 'primary'
     */
    headerColor?: HeaderColor;
    /**
     * Shadow depth, corresponds to `dp` in the spec.
     * It accepts values between 0 and 24 inclusive.
     * @default 1
     */
    headerElevation?: Elevation;
    /**
     * Callback fired when the Sidemenu requests to be closed or opened.
     */
    toggleSidemenu?: ToggleSidemenuFunction;
    /**
     * Is sidemenu minimizible.
     */
    minimizable?: boolean;
    /**
     * Menu icon. Default: MenuIcon.
     */
    menuIcon?: React.ReactNode;
    /**
     * Expand icon. Default ExpandIcon.
     */
    expandIcon?: React.ReactNode;
    /**
     * Collapse icon. Default CollapseIcon.
     */
    collapseIcon?: React.ReactNode;
    /**
     * Minimize icon. Default ArrowLeftIcon
     */
    minimizeIcon?: React.ReactNode;
    /**
     * Relative action button size.
     */
    actionSize?: ActionSize;
    /**
     * Underlying Paper props.
     */
    PaperProps?: PaperProps;
    /**
     * Underlying List props.
     */
    ListProps?: ListProps;
    /**
     * Underlying IconButton props.
     */
    IconButtonProps?: IconButtonProps;
}
/**
 * Application's side menu.
 */
declare const Sidemenu: React.ForwardRefExoticComponent<Pick<SidemenuProps, "children" | "variant" | "title" | "color" | "className" | "onSubmit" | "classes" | "defaultChecked" | "defaultValue" | "suppressContentEditableWarning" | "suppressHydrationWarning" | "accessKey" | "autoFocus" | "contentEditable" | "contextMenu" | "dir" | "draggable" | "hidden" | "id" | "lang" | "nonce" | "placeholder" | "slot" | "spellCheck" | "style" | "tabIndex" | "translate" | "radioGroup" | "role" | "about" | "content" | "datatype" | "inlist" | "prefix" | "property" | "rel" | "resource" | "rev" | "typeof" | "vocab" | "autoCapitalize" | "autoCorrect" | "autoSave" | "itemProp" | "itemScope" | "itemType" | "itemID" | "itemRef" | "results" | "security" | "unselectable" | "inputMode" | "is" | "aria-activedescendant" | "aria-atomic" | "aria-autocomplete" | "aria-busy" | "aria-checked" | "aria-colcount" | "aria-colindex" | "aria-colspan" | "aria-controls" | "aria-current" | "aria-describedby" | "aria-details" | "aria-disabled" | "aria-dropeffect" | "aria-errormessage" | "aria-expanded" | "aria-flowto" | "aria-grabbed" | "aria-haspopup" | "aria-hidden" | "aria-invalid" | "aria-keyshortcuts" | "aria-label" | "aria-labelledby" | "aria-level" | "aria-live" | "aria-modal" | "aria-multiline" | "aria-multiselectable" | "aria-orientation" | "aria-owns" | "aria-placeholder" | "aria-posinset" | "aria-pressed" | "aria-readonly" | "aria-relevant" | "aria-required" | "aria-roledescription" | "aria-rowcount" | "aria-rowindex" | "aria-rowspan" | "aria-selected" | "aria-setsize" | "aria-sort" | "aria-valuemax" | "aria-valuemin" | "aria-valuenow" | "aria-valuetext" | "dangerouslySetInnerHTML" | "onCopy" | "onCopyCapture" | "onCut" | "onCutCapture" | "onPaste" | "onPasteCapture" | "onCompositionEnd" | "onCompositionEndCapture" | "onCompositionStart" | "onCompositionStartCapture" | "onCompositionUpdate" | "onCompositionUpdateCapture" | "onFocus" | "onFocusCapture" | "onBlur" | "onBlurCapture" | "onChange" | "onChangeCapture" | "onBeforeInput" | "onBeforeInputCapture" | "onInput" | "onInputCapture" | "onReset" | "onResetCapture" | "onSubmitCapture" | "onInvalid" | "onInvalidCapture" | "onLoad" | "onLoadCapture" | "onError" | "onErrorCapture" | "onKeyDown" | "onKeyDownCapture" | "onKeyPress" | "onKeyPressCapture" | "onKeyUp" | "onKeyUpCapture" | "onAbort" | "onAbortCapture" | "onCanPlay" | "onCanPlayCapture" | "onCanPlayThrough" | "onCanPlayThroughCapture" | "onDurationChange" | "onDurationChangeCapture" | "onEmptied" | "onEmptiedCapture" | "onEncrypted" | "onEncryptedCapture" | "onEnded" | "onEndedCapture" | "onLoadedData" | "onLoadedDataCapture" | "onLoadedMetadata" | "onLoadedMetadataCapture" | "onLoadStart" | "onLoadStartCapture" | "onPause" | "onPauseCapture" | "onPlay" | "onPlayCapture" | "onPlaying" | "onPlayingCapture" | "onProgress" | "onProgressCapture" | "onRateChange" | "onRateChangeCapture" | "onResize" | "onResizeCapture" | "onSeeked" | "onSeekedCapture" | "onSeeking" | "onSeekingCapture" | "onStalled" | "onStalledCapture" | "onSuspend" | "onSuspendCapture" | "onTimeUpdate" | "onTimeUpdateCapture" | "onVolumeChange" | "onVolumeChangeCapture" | "onWaiting" | "onWaitingCapture" | "onAuxClick" | "onAuxClickCapture" | "onClick" | "onClickCapture" | "onContextMenu" | "onContextMenuCapture" | "onDoubleClick" | "onDoubleClickCapture" | "onDrag" | "onDragCapture" | "onDragEnd" | "onDragEndCapture" | "onDragEnter" | "onDragEnterCapture" | "onDragExit" | "onDragExitCapture" | "onDragLeave" | "onDragLeaveCapture" | "onDragOver" | "onDragOverCapture" | "onDragStart" | "onDragStartCapture" | "onDrop" | "onDropCapture" | "onMouseDown" | "onMouseDownCapture" | "onMouseEnter" | "onMouseLeave" | "onMouseMove" | "onMouseMoveCapture" | "onMouseOut" | "onMouseOutCapture" | "onMouseOver" | "onMouseOverCapture" | "onMouseUp" | "onMouseUpCapture" | "onSelect" | "onSelectCapture" | "onTouchCancel" | "onTouchCancelCapture" | "onTouchEnd" | "onTouchEndCapture" | "onTouchMove" | "onTouchMoveCapture" | "onTouchStart" | "onTouchStartCapture" | "onPointerDown" | "onPointerDownCapture" | "onPointerMove" | "onPointerMoveCapture" | "onPointerUp" | "onPointerUpCapture" | "onPointerCancel" | "onPointerCancelCapture" | "onPointerEnter" | "onPointerEnterCapture" | "onPointerLeave" | "onPointerLeaveCapture" | "onPointerOver" | "onPointerOverCapture" | "onPointerOut" | "onPointerOutCapture" | "onGotPointerCapture" | "onGotPointerCaptureCapture" | "onLostPointerCapture" | "onLostPointerCaptureCapture" | "onScroll" | "onScrollCapture" | "onWheel" | "onWheelCapture" | "onAnimationStart" | "onAnimationStartCapture" | "onAnimationEnd" | "onAnimationEndCapture" | "onAnimationIteration" | "onAnimationIterationCapture" | "onTransitionEnd" | "onTransitionEndCapture" | "components" | "componentsProps" | "slotProps" | "slots" | "sx" | "key" | "elevation" | "transitionDuration" | "container" | "IconButtonProps" | "closeAfterTransition" | "disableAutoFocus" | "disableEnforceFocus" | "disableEscapeKeyDown" | "disablePortal" | "disableRestoreFocus" | "disableScrollLock" | "hideBackdrop" | "keepMounted" | "onBackdropClick" | "BackdropComponent" | "BackdropProps" | "PaperProps" | "menuIcon" | "ListProps" | "toggleSidemenu" | "anchor" | "ModalProps" | "SlideProps" | "allowSwipeInChildren" | "disableBackdropTransition" | "disableDiscovery" | "disableSwipeToOpen" | "hysteresis" | "minFlingVelocity" | "SwipeAreaProps" | "swipeAreaWidth" | "state" | "minimizable" | "clipped" | "borderless" | "headerContent" | "headerColor" | "headerElevation" | "expandIcon" | "collapseIcon" | "minimizeIcon" | "actionSize"> & React.RefAttributes<unknown>>;
export default Sidemenu;
