import { CollapseProps, TooltipProps } from '@mui/material';
import { ListProps } from '@mui/material/List';
import { ListItemProps } from '@mui/material/ListItem';
import { ListItemIconProps } from '@mui/material/ListItemIcon';
import { ListItemTextProps } from '@mui/material/ListItemText';
import React from 'react';
import { BaseProps } from '../../../types/props';
import { StandardColor } from '../../../types/color';
import { ActionSize } from '../../../types/action';
export interface SidemenuSubmenuProps extends BaseProps, Omit<ListProps, 'title'> {
    /**
     * Optional icon used to visually identify submenu.
     */
    icon?: React.ReactNode;
    /**
     * Optional icon used to visually identify expanded submenu.
     */
    expandedIcon?: React.ReactNode;
    /**
     * Specifies if submenu items are indented.
     */
    indentItems?: boolean;
    /**
     * Optional action title.
     */
    title?: React.ReactNode;
    /**
     * Color of the action.
     */
    color?: StandardColor;
    /**
     * Specifies if submenu is disabled.
     */
    disabled?: boolean;
    /**
     * Is submenu expanded.
     */
    expanded?: boolean;
    /**
     * Optional expand icon for collapsed submenu.
     */
    expandIcon?: React.ReactNode;
    /**
     * Optional collapse icon for expanded submenu.
     */
    collapseIcon?: React.ReactNode;
    /**
     * Callback function to call onClick in order to close 'temporary' sidemenu. Internally used.
     */
    toggleTemporarySidemenu?: any;
    /**
     * Specifies hierarchical level (depth) of the sidemenu. Starts from 0. Internally used.
     */
    level?: number;
    /**
     * Specifies if sidemenu is minimizable. This applies only for sidemenu with permanent variant. Internaly used.
     */
    minimizable?: boolean;
    /**
     * Specifies if sidemenu is minimized.
     */
    minimized?: boolean;
    /**
     * Underlying ListItem props.
     */
    ListItemProps?: ListItemProps;
    /**
     * Underlying ListItemIcon props.
     */
    ListItemIconProps?: ListItemIconProps;
    /**
     * Underlying ListItemText props.
     */
    ListItemTextProps?: ListItemTextProps;
    /**
     * Tooltip for the action.
     */
    tooltip?: React.ReactNode;
    /**
     * Underlying tooltip props.
     */
    TooltipProps?: Omit<TooltipProps, 'title' | 'children'>;
    /**
     * Undelrying Collapse props.
     */
    CollapseProps?: CollapseProps;
    /**
     * Relative submenu item size.
     */
    size?: ActionSize;
}
declare const SidemenuSubmenu: React.ForwardRefExoticComponent<Pick<SidemenuSubmenuProps, "children" | "title" | "icon" | "color" | "size" | "disabled" | "tooltip" | "TooltipProps" | "className" | "onSubmit" | "classes" | "defaultChecked" | "defaultValue" | "suppressContentEditableWarning" | "suppressHydrationWarning" | "accessKey" | "autoFocus" | "contentEditable" | "contextMenu" | "dir" | "draggable" | "hidden" | "id" | "lang" | "nonce" | "placeholder" | "slot" | "spellCheck" | "style" | "tabIndex" | "translate" | "radioGroup" | "role" | "about" | "content" | "datatype" | "inlist" | "prefix" | "property" | "rel" | "resource" | "rev" | "typeof" | "vocab" | "autoCapitalize" | "autoCorrect" | "autoSave" | "itemProp" | "itemScope" | "itemType" | "itemID" | "itemRef" | "results" | "security" | "unselectable" | "inputMode" | "is" | "aria-activedescendant" | "aria-atomic" | "aria-autocomplete" | "aria-busy" | "aria-checked" | "aria-colcount" | "aria-colindex" | "aria-colspan" | "aria-controls" | "aria-current" | "aria-describedby" | "aria-details" | "aria-disabled" | "aria-dropeffect" | "aria-errormessage" | "aria-expanded" | "aria-flowto" | "aria-grabbed" | "aria-haspopup" | "aria-hidden" | "aria-invalid" | "aria-keyshortcuts" | "aria-label" | "aria-labelledby" | "aria-level" | "aria-live" | "aria-modal" | "aria-multiline" | "aria-multiselectable" | "aria-orientation" | "aria-owns" | "aria-placeholder" | "aria-posinset" | "aria-pressed" | "aria-readonly" | "aria-relevant" | "aria-required" | "aria-roledescription" | "aria-rowcount" | "aria-rowindex" | "aria-rowspan" | "aria-selected" | "aria-setsize" | "aria-sort" | "aria-valuemax" | "aria-valuemin" | "aria-valuenow" | "aria-valuetext" | "dangerouslySetInnerHTML" | "onCopy" | "onCopyCapture" | "onCut" | "onCutCapture" | "onPaste" | "onPasteCapture" | "onCompositionEnd" | "onCompositionEndCapture" | "onCompositionStart" | "onCompositionStartCapture" | "onCompositionUpdate" | "onCompositionUpdateCapture" | "onFocus" | "onFocusCapture" | "onBlur" | "onBlurCapture" | "onChange" | "onChangeCapture" | "onBeforeInput" | "onBeforeInputCapture" | "onInput" | "onInputCapture" | "onReset" | "onResetCapture" | "onSubmitCapture" | "onInvalid" | "onInvalidCapture" | "onLoad" | "onLoadCapture" | "onError" | "onErrorCapture" | "onKeyDown" | "onKeyDownCapture" | "onKeyPress" | "onKeyPressCapture" | "onKeyUp" | "onKeyUpCapture" | "onAbort" | "onAbortCapture" | "onCanPlay" | "onCanPlayCapture" | "onCanPlayThrough" | "onCanPlayThroughCapture" | "onDurationChange" | "onDurationChangeCapture" | "onEmptied" | "onEmptiedCapture" | "onEncrypted" | "onEncryptedCapture" | "onEnded" | "onEndedCapture" | "onLoadedData" | "onLoadedDataCapture" | "onLoadedMetadata" | "onLoadedMetadataCapture" | "onLoadStart" | "onLoadStartCapture" | "onPause" | "onPauseCapture" | "onPlay" | "onPlayCapture" | "onPlaying" | "onPlayingCapture" | "onProgress" | "onProgressCapture" | "onRateChange" | "onRateChangeCapture" | "onResize" | "onResizeCapture" | "onSeeked" | "onSeekedCapture" | "onSeeking" | "onSeekingCapture" | "onStalled" | "onStalledCapture" | "onSuspend" | "onSuspendCapture" | "onTimeUpdate" | "onTimeUpdateCapture" | "onVolumeChange" | "onVolumeChangeCapture" | "onWaiting" | "onWaitingCapture" | "onAuxClick" | "onAuxClickCapture" | "onClick" | "onClickCapture" | "onContextMenu" | "onContextMenuCapture" | "onDoubleClick" | "onDoubleClickCapture" | "onDrag" | "onDragCapture" | "onDragEnd" | "onDragEndCapture" | "onDragEnter" | "onDragEnterCapture" | "onDragExit" | "onDragExitCapture" | "onDragLeave" | "onDragLeaveCapture" | "onDragOver" | "onDragOverCapture" | "onDragStart" | "onDragStartCapture" | "onDrop" | "onDropCapture" | "onMouseDown" | "onMouseDownCapture" | "onMouseEnter" | "onMouseLeave" | "onMouseMove" | "onMouseMoveCapture" | "onMouseOut" | "onMouseOutCapture" | "onMouseOver" | "onMouseOverCapture" | "onMouseUp" | "onMouseUpCapture" | "onSelect" | "onSelectCapture" | "onTouchCancel" | "onTouchCancelCapture" | "onTouchEnd" | "onTouchEndCapture" | "onTouchMove" | "onTouchMoveCapture" | "onTouchStart" | "onTouchStartCapture" | "onPointerDown" | "onPointerDownCapture" | "onPointerMove" | "onPointerMoveCapture" | "onPointerUp" | "onPointerUpCapture" | "onPointerCancel" | "onPointerCancelCapture" | "onPointerEnter" | "onPointerEnterCapture" | "onPointerLeave" | "onPointerLeaveCapture" | "onPointerOver" | "onPointerOverCapture" | "onPointerOut" | "onPointerOutCapture" | "onGotPointerCapture" | "onGotPointerCaptureCapture" | "onLostPointerCapture" | "onLostPointerCaptureCapture" | "onScroll" | "onScrollCapture" | "onWheel" | "onWheelCapture" | "onAnimationStart" | "onAnimationStartCapture" | "onAnimationEnd" | "onAnimationEndCapture" | "onAnimationIteration" | "onAnimationIterationCapture" | "onTransitionEnd" | "onTransitionEndCapture" | "sx" | "key" | "dense" | "CollapseProps" | "ListItemTextProps" | "ListItemIconProps" | "ListItemProps" | "expanded" | "disablePadding" | "subheader" | "minimized" | "minimizable" | "expandIcon" | "collapseIcon" | "toggleTemporarySidemenu" | "level" | "expandedIcon" | "indentItems"> & React.RefAttributes<unknown>>;
export default SidemenuSubmenu;
