import { ColumnContent, ColumnFormat, HiddenBreakpoint, TableCellAlign } from '../../../../types/datatable';
import React, { ReactNode } from 'react';
import { BaseProps } from '../../../../types/props';
import { TableCellProps } from '@mui/material';
interface getColumnValueProps {
    name?: string;
    item?: any;
    getValue?: (item: any) => any;
    format?: ColumnFormat;
}
export declare const getColumnValue: (props: getColumnValueProps) => any;
export interface ColumnProps extends BaseProps {
    /**
     * Column name: used to bind to data source.
     */
    name?: string;
    /**
     * Title for the column's header.
     */
    label?: ReactNode;
    /**
     * table cell content align.
     */
    align?: TableCellAlign;
    /**
     * Specifies if column is hidden when screen size exceeds some treshhold.
     */
    hiddenBreakpoint?: HiddenBreakpoint;
    /**
     * Specifies if column is hidden.
     */
    hidden?: boolean;
    /**
     * Column content.
     */
    renderContent?: ColumnContent;
    /**
     * Adornment at the start of column.
     */
    renderStartAdornment?: ColumnContent;
    /**
     * Adornment at the endr of column.
     */
    renderEndAdornment?: ColumnContent;
    /**
     * Data in the row.
     */
    item?: any;
    /**
     * Function to format column value.
     */
    format?: ColumnFormat;
    /**
     * Underlying TableCell props.
     */
    TableCellProps?: Omit<TableCellProps, 'children' | 'variant'>;
    /**
     * Specify callback function to return value.
     */
    getValue?: (item: any) => any;
}
/**
 * This is just an Datatable child interface component.
 * Basically it's just propagated component to the underlying DatatableDataCell,
 * which has some additional internally used props.
 */
declare const Column: React.ForwardRefExoticComponent<ColumnProps & React.RefAttributes<unknown>>;
export default Column;
