import React, { ReactNode } from 'react';
import { FilterOptions, FilterSize, FilterVariant } from '../../../types/search';
import { FieldInputVariant, FieldMargin } from '../../../types/field';
import { BoxProps } from '@mui/system';
import { BaseProps } from '../../../types/props';
/**
 * Object containing configuration for array of filters, such are children in SearchBar component.
 */
export interface FiltersProps {
    [key: string]: any;
}
/**
 * Properties ot he filter control.
 */
export interface FilterProps extends BaseProps {
    /**
     * Filter name. Used as a underlying HTML name as well as property name provided to the search service.
     */
    name: string;
    /**
     * Default value.
     */
    defaultValue?: any;
    /**
     * Filter variant.
     */
    variant?: FilterVariant;
    /**
     * Filter label.
     */
    label?: ReactNode;
    /**
     * Filter placeholder.
     */
    placeholder?: string;
    /**
     * Options for filtering.
     */
    options?: FilterOptions;
    /**
     * Specifies if filter is hidden. This requires 'defaultValue' set  in order to have sense.
     */
    hidden?: boolean;
    /**
     * Props applied to the underlying `material-ui` component.
     */
    componentProps?: any;
    /**
     * Filter container Box props.
     */
    BoxProps?: BoxProps;
    /**
     * Variant of the underlying TextField component.
     */
    inputVariant?: FieldInputVariant;
    /**
     * Relative size of the component.
     */
    size?: FilterSize;
    /**
     * Relative margin of the component.
     */
    margin?: FieldMargin;
    /**
     * Callback function called when filter value has been changed.
     */
    onChange?: (name: string, value: any) => void;
    /**
     * Optional callback function which could be used to transform filter value.
     */
    getFilterOutput?: (filter: any) => any;
}
declare const Filter: React.ForwardRefExoticComponent<FilterProps & React.RefAttributes<unknown>>;
export default Filter;
