import { BoxProps, DividerProps, IconButtonProps, PaperProps, TypographyProps } from '@mui/material';
import React, { ReactElement } from 'react';
import { HeaderAdornment, PageTitle, PageWidth } from '../../types/page';
import { ActionGroupProps } from '../actions/actionGroup/actionGroup';
export declare const HeaderRoot: any;
export declare const HeaderPaperRoot: any;
export interface HeaderProps extends Omit<BoxProps, 'title'> {
    renderStartAdornment?: HeaderAdornment;
    renderEndAdornment?: HeaderAdornment;
    /**
     * The text to be shown as a title of the page. In case when callback function is used input parameter is taken from 'data' prop.
     */
    title?: PageTitle;
    /**
     * The text to be shown as a subtitle of the page. In case when callback function is used input parameter is taken from 'data' prop.
     */
    subtitle?: PageTitle;
    /**
     * Specifies if there is a visual divider between title and subtitle.
     */
    hasDivider?: boolean;
    /**
     * Title adornment.
     */
    titleAdornment?: HeaderAdornment;
    /**
     * Header actions.
     */
    actionGroup?: ReactElement<ActionGroupProps>;
    /**
     * Object used as as data for the header.
     * This is usualy data of the header container: e.g., Part or Page.
     */
    data?: any;
    /**
     * Page header width.
     */
    width?: PageWidth;
    /**
     * Page header content width.
     */
    contentWidth?: PageWidth;
    /**
     * Specifies if Header is wrapped with Box instead of Paper.
     */
    transparent?: boolean;
    /**
     * Title group Box props.
     */
    TitleBoxProps?: BoxProps;
    /**
     * Underlaying title Typographtyprops;
     */
    TitleTypographyProps?: TypographyProps;
    /**
     * Underlaying subtitle Typography props;
     */
    SubtitleTypographyProps?: TypographyProps;
    /**
     * Underlying title group (back, title, divide, subtitle) Box props.
     */
    TitleAndSubtitleBoxProps?: BoxProps;
    /**
     * Header content Box props.
     */
    ContentBoxProps?: BoxProps;
    /**
     * Underlaying Divider props;
     */
    DividerProps?: DividerProps;
    /**
     * Paper props in case when header is not transparent.
     */
    PaperProps?: PaperProps;
}
interface HeaderBackProps extends IconButtonProps {
    /**
     * Back icon.
     */
    backIcon?: React.ReactNode;
}
export declare const HeaderBack: ({ backIcon, ...other }: HeaderBackProps) => React.JSX.Element;
interface HeaderTitleProps {
    /**
     * The text to be shown as a title of the page. In case when callback function is used input parameter is taken from 'data' prop.
     */
    title?: PageTitle;
    /**
     * Title adornment.
     */
    titleAdornment?: HeaderAdornment;
    /**
     * Header data. Propageted from Header component which, agint, get it from its parent: e.g., Page or Part.
     */
    data?: any;
    /**
     * Underlaying title Typographtyprops;
     */
    TitleTypographyProps?: TypographyProps;
}
export declare const HeaderTitle: ({ title: _title, titleAdornment: _titleAdornment, data, TitleTypographyProps }: HeaderTitleProps) => React.JSX.Element;
interface HeaderSubtitleProps {
    /**
     * The text to be shown as a subtitle of the page. In case when callback function is used input parameter is taken from 'data' prop.
     */
    subtitle?: PageTitle;
    /**
     * Header data set by its parent container: e.g., Part or Page.
     */
    data?: any;
    /**
     * Underlaying subtitle Typography props;
     */
    SubtitleTypographyProps?: TypographyProps;
}
export declare const HeaderSubtitle: ({ subtitle, data, SubtitleTypographyProps }: HeaderSubtitleProps) => React.JSX.Element;
interface HeaderContentProps extends BoxProps {
}
export declare const HeaderContent: ({ children, ...other }: HeaderContentProps) => React.JSX.Element;
interface HeaderActionsProps extends ActionGroupProps {
}
export declare const HeaderActions: ({ variant, className, ...other }: HeaderActionsProps) => React.JSX.Element;
interface HeaderDividerProps extends DividerProps {
}
export declare const HeaderDivider: ({ orientation, ...other }: HeaderDividerProps) => React.JSX.Element;
interface HeaderIconProps extends BoxProps {
    icon?: React.ReactNode;
}
export declare const HeaderIcon: ({ icon, ...other }: HeaderIconProps) => React.JSX.Element;
export declare const Header: React.ForwardRefExoticComponent<Pick<any, string | number | symbol> & React.RefAttributes<unknown>>;
export {};
