import { Error } from '../types/error';
export interface FetchServiceResponse {
    /**
     * It's ok: fetch executed successfully.
     */
    ok: boolean;
    /**
     * Result of the fetch.
     */
    data?: any | Error | Array<Error>;
}
export declare type TransformResponseData = (data: any) => any;
export interface FetchServiceOptions {
    /**
     * Enable debug log.
     */
    enableLog?: boolean;
    /**
     * Service level method to generate 'headers' value for the RequestInit object.
     * Usually used to set 'Content-Type' or 'Authorization' headers.
     */
    getHeaders?: () => Promise<HeadersInit>;
    /**
     * Service level method to generate 'headers' value for the RequestInit object when FormData is used.
     */
    getFormDataHeaders?: () => HeadersInit;
    /**
     * Method to get message for the various error codes which could occur during fetch processing.
     */
    getMessage: (code: string, defaultMessage: string) => string;
    /**
     * Method called to handle errors returned when response.ok is false.
     */
    handleErrors?: (response: Response, data?: any) => Array<Error> | Error;
    /**
     * Service level method called to initialize fetch request.
     * Could be overriden at for each call.
     */
    getInit?: () => RequestInit;
}
export declare class FetchService {
    options: FetchServiceOptions;
    constructor(options: FetchServiceOptions);
    _getHeaders: () => Promise<HeadersInit>;
    _getFormDataHeaders: () => HeadersInit;
    _getMessage: (code: string, defaultMessage: string) => string;
    _getInit: () => RequestInit;
    /**
     * Handles is APi responded with error: !response.ok
     *
     * error handler callback could be initialized using FetchServiceOptions.handleErrors
     * otherwise default handler will be used
     * @param response
     * @returns
     */
    _handleErrors: (response: Response) => Promise<Error | Error[]>;
    undefinedResponse: () => {
        ok: boolean;
        data: {
            code: string;
            severity: string;
            message: string;
        };
    };
    networkErrorResponse: () => {
        ok: boolean;
        data: {
            code: string;
            severity: string;
            message: string;
        };
    };
    get: (url: string, init?: RequestInit | undefined, transformResponseData?: TransformResponseData | undefined) => Promise<FetchServiceResponse>;
    postRequest: (url: string, init: RequestInit, transformResponseData?: TransformResponseData | undefined) => Promise<FetchServiceResponse>;
    post: (url: string, data?: any, init?: Pick<RequestInit, "body" | "mode" | "integrity" | "referrerPolicy" | "headers" | "cache" | "credentials" | "keepalive" | "redirect" | "referrer" | "signal" | "window"> | undefined, transformResponseData?: TransformResponseData | undefined) => Promise<FetchServiceResponse>;
    patchRequest: (url: string, init?: RequestInit | undefined, transformResponseData?: TransformResponseData | undefined) => Promise<FetchServiceResponse>;
    patch: (url: string, data?: any, init?: Pick<RequestInit, "body" | "mode" | "integrity" | "referrerPolicy" | "headers" | "cache" | "credentials" | "keepalive" | "redirect" | "referrer" | "signal" | "window"> | undefined, transformResponseData?: TransformResponseData | undefined) => Promise<FetchServiceResponse>;
    putRequest: (url: string, init: RequestInit, transformResponseData?: TransformResponseData | undefined) => Promise<FetchServiceResponse>;
    put: (url: string, data?: any, init?: Pick<RequestInit, "body" | "mode" | "integrity" | "referrerPolicy" | "headers" | "cache" | "credentials" | "keepalive" | "redirect" | "referrer" | "signal" | "window"> | undefined, transformResponseData?: TransformResponseData | undefined) => Promise<FetchServiceResponse>;
    delete: (url: string, data?: any, init?: Pick<RequestInit, "body" | "mode" | "integrity" | "referrerPolicy" | "headers" | "cache" | "credentials" | "keepalive" | "redirect" | "referrer" | "signal" | "window"> | undefined, transformResponseData?: TransformResponseData | undefined) => Promise<FetchServiceResponse>;
    postFormData: (url: string, formData: FormData, init?: Pick<RequestInit, "mode" | "integrity" | "referrerPolicy" | "headers" | "cache" | "credentials" | "keepalive" | "redirect" | "referrer" | "signal" | "window"> | undefined, transformResponseData?: TransformResponseData | undefined) => Promise<FetchServiceResponse>;
    putFormData: (url: string, formData: FormData, init?: Pick<RequestInit, "mode" | "integrity" | "referrerPolicy" | "headers" | "cache" | "credentials" | "keepalive" | "redirect" | "referrer" | "signal" | "window"> | undefined, transformResponseData?: TransformResponseData | undefined) => Promise<FetchServiceResponse>;
    patchFormData: (url: string, formData: FormData, init?: Pick<RequestInit, "mode" | "integrity" | "referrerPolicy" | "headers" | "cache" | "credentials" | "keepalive" | "redirect" | "referrer" | "signal" | "window"> | undefined, transformResponseData?: TransformResponseData | undefined) => Promise<FetchServiceResponse>;
    log: (message?: any, ...optionalParameters: any[]) => void;
}
