import { ActionColor } from './action';
import React from 'react';
import { PropTypes } from '@mui/material';
import { ActionProps } from '../components/actions/action/action';
/**
 * Menu item variant type.
 */
export declare type MenuItemVariant = 'action' | 'divider' | 'submenu';
/**
 * Action menu item.
 */
export declare type ActionMenuItem = Omit<ActionProps, 'variant'>;
/**
 * Submenu item.
 */
export interface SubmenuItem {
    /**
     * Optional icon used to visually identify action.
     */
    icon?: React.ReactNode;
    /**
     * Optional action title.
     */
    title?: React.ReactNode;
    /**
     * Color of the action.
     */
    color?: ActionColor;
    /**
     * Tooltip for the action.
     */
    tooltip?: any;
    /**
     * Is submenu expanded.
     */
    expanded?: boolean;
    /**
     * Submenu.
     */
    submenu: Menu;
}
/**
 * Menu item.
 */
export interface MenuItem {
    item?: ActionMenuItem | SubmenuItem;
    variant: MenuItemVariant;
}
/**
 * Menu specified as an array of action options.
 */
export interface Menu {
    items: Array<MenuItem>;
}
/**
 * Header color.
 */
export declare type HeaderColor = PropTypes.Color | 'transparent';
/**
 * Sidemenu state.
 */
export declare type SidemenuState = 'expanded' | 'hidden' | 'minimized';
/**
 * Sidemenu variant.
 */
export declare type SidemenuVariant = 'permanent' | 'persistent' | 'temporary';
/**
 * Footer position.
 */
export declare type FooterPosition = 'sticky' | 'fixed';
/**
 * Footer color.
 */
export declare type FooterColor = HeaderColor;
