import React from 'react';
import { StandardColor } from './color';
/**
 * Option color.
 */
export declare type OptionColor = StandardColor | 'default';
/**
 * Option identifier.
 */
export declare type OptionIdentifier = string | number;
/**
 * Option properties.
 */
export interface Option {
    /**
     * Identifier of the option.
     */
    id: OptionIdentifier;
    /**
     * Localized label of the option
     */
    label: string;
    /**
     * Option content to render. If not defined label will be rendered.
     */
    content?: React.ReactNode;
    /**
     * Color of the option.
     */
    color?: OptionColor;
    /**
     * Underlying item: used when more than id, name and/or code is needed.
     */
    item?: any;
}
/**
 * Returns option label.
 * @param options Array of options.
 * @param id Option identifier.
 * @returns Option name.
 */
export declare const getOptionLabel: (options: Array<Option>, id: OptionIdentifier) => React.Key;
/**
 * Returns option for option identifier.
 * @param options Array of options.
 * @param id Option identifier.
 * @returns Option.
 */
export declare const getOption: (options: Array<Option>, id: OptionIdentifier) => Option | undefined;
/**
 * Returns option color.
 * @param options Array of options.
 * @param id Option identifier.
 * @returns Option color.
 */
export declare const getColor: (options: Array<Option>, id: OptionIdentifier) => "primary" | "secondary" | "success" | "error" | "info" | "warning" | "default" | undefined;
/**
 * Returns array of options. IN case when options are represented with function executes function which returns array of options.
 * @param options
 * @param item
 * @returns
 */
export declare const getOptions: (options?: any, item?: any) => any;
