import { Error } from './error';
import { FilterOptions, Filters } from './search';
export declare class ListWithTotalCount<T> {
    items: Array<T>;
    totalCount: number;
    constructor(items: Array<T>, totalCount: number);
}
export declare const isServiceResponse: (response: any) => boolean;
export declare class ServiceResponse<T> {
    ok: boolean;
    response?: T;
    errors?: Array<Error>;
    constructor(ok: boolean, response?: T | undefined, errors?: Array<Error>);
}
export declare const ok: () => ServiceResponse<unknown>;
export declare const serviceError: (error: string) => ServiceResponse<undefined>;
export declare const notImplementedError: (parameter?: string | undefined) => ServiceResponse<undefined>;
export declare const notFoundError: (parameter?: string | undefined) => ServiceResponse<undefined>;
export declare const undefinedParameterError: (parameter?: string | undefined) => ServiceResponse<undefined>;
export declare type GetListResponse<T> = ServiceResponse<ListWithTotalCount<T> | undefined>;
export declare type ServiceGetListMethod<T> = (filters: Filters, page: number, rowsPerPage: number) => Promise<GetListResponse<T>>;
export declare type ServiceGetMethod<T> = (params: any) => Promise<ServiceResponse<T | undefined>>;
export declare type ServiceSubmitMethod = (data: any) => Promise<ServiceResponse<any>>;
export interface IGetList<T> {
    getList: ServiceGetListMethod<T>;
}
export interface IGet<T> {
    get: ServiceGetMethod<T>;
}
export interface IAdd {
    add: ServiceSubmitMethod;
}
export interface IUpdate {
    update: ServiceSubmitMethod;
}
export interface IDelete {
    delete: ServiceSubmitMethod;
}
export interface ISearch {
    search: FilterOptions;
}
